.. Pypeline documentation master file, created by
   sphinx-quickstart on Tue Oct 5 14:55:27 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Pypeline's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 2
   :glob:
   
   tour
   api/api

Miscellaneous Links of Interest
================================

`GitHub Markup <http://github.com/github/markup>`_
    GitHub's original implementation of Markup in Ruby.
   
Indices and tables
===================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

